exceptiontools.SpannerPopulationError
=====================================

.. abjad-lineage:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError

.. autoclass:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__unicode__
   :noindex:
